--------------------------------------------------------------
--FINTRAC SAR TABLE CREATION TEMPLATE
--------------------------------------------------------------
--This script is a template for creating the tables required 
--for FINTRAC SAR.
--
--This script is only a template.  It must be customized
--to the physical environment and volume of data expected. 
--
--
--This script must be run as a user with SYSADM or DBADM privileges.
--
--It is assumed that the users 'AMLCTR' and 'AMLAPP' exist in
--UNIX (or other authentication mechanism).
--
--IMPORTANT NOTE:
--      This script should be run after the db2_base_sar_ddl.sql 
--      ONLY IF the FINTRAC customization is being implemented.
--------------------------------------------------------------
--------------------------------------------------------------

CREATE TABLE AMLCTR.FIN_CONTACT_CONTROL
(
	REPORT_TYPE  CHAR(4)  NOT NULL ,
	RPT_ENT_CNTCT_SURNAME  VARCHAR(20)  ,
	RPT_ENT_CNTCT_GIVEN_NAME  VARCHAR(15)  ,
	RPT_ENT_CNTCT_OTH_NAME  VARCHAR(10)  ,
	RPT_ENT_CNTCT_PH  VARCHAR(20)  ,
	RPT_ENT_CNTCT_PH_EXT  NUMERIC(10,0)  
)
;


ALTER TABLE AMLCTR.FIN_CONTACT_CONTROL
	ADD CONSTRAINT  XPKCONTACT PRIMARY KEY (REPORT_TYPE)
;


CREATE TABLE AMLCTR.FIN_ENTITY_CONTROL
(
	ENTITY_ID  VARCHAR(20)  ,
	ENTITY_NAME  VARCHAR(50)  ,
	ENTITY_TYPE  CHAR(1)  ,
	LAST_MODIFIED  NUMERIC(8,0)  ,
	PKI_NUMBER  VARCHAR(20)  
)
;


CREATE TABLE AMLCTR.FINTRAC_COUNTRY_LOOKUP
(
	FINTRAC_COUNTRY  CHAR(2)  ,
	WIRES_COUNTRY  CHAR(2)  
)
;


CREATE TABLE AMLCTR.FINTRAC_TRANSACTION_TYPE_LOOKU
(
	TRANSACTION_TYPE_KEY  INTEGER  NOT NULL ,
	DISP_TYPE  CHAR(1)  ,
	TRAN_METHOD  CHAR(1)  ,
	DISP_TYPE_OTHER  VARCHAR(50)  ,
	TRAN_METHOD_OTHER  VARCHAR(50)  ,
	DISPOSITION_OF_FUNDS  CHAR(1)  ,
	DISPOSITION_OTHER  VARCHAR(50)  
)
;


ALTER TABLE AMLCTR.FINTRAC_TRANSACTION_TYPE_LOOKU
	ADD CONSTRAINT  XPKFINTRAC_TRANSACTION_TYPE_LO PRIMARY KEY (TRANSACTION_TYPE_KEY)
;


CREATE TABLE AMLCTR.IDENTITY_DOCUMENT
(
	ID_CODE  CHAR(3)  ,
	ID_DESC  VARCHAR(30)  ,
	FINTRAC_ID  CHAR(1)  
)
;


CREATE TABLE AMLCTR.LSTR_ACTION
(
	PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	PART_ID  CHAR(2)  ,
	ACT_ACTION_DESC  VARCHAR(400)  
)
;


ALTER TABLE AMLCTR.LSTR_ACTION
	ADD CONSTRAINT  XPKLSTR_ACTION PRIMARY KEY (PART_SEQ_NUM,SAR_ID)
;


CREATE TABLE AMLCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE
(
	LOGICAL_SAR_ID  NUMERIC(15,0)  NOT NULL ,
	PHYSICAL_SAR_ID  NUMERIC(15,0)  NOT NULL 
)
;


ALTER TABLE AMLCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE
	ADD CONSTRAINT  XPKLSTR_LOGICAL_PHYSICAL_BRIDG PRIMARY KEY (LOGICAL_SAR_ID,PHYSICAL_SAR_ID)
;


CREATE TABLE AMLCTR.LSTR_NARATIVE
(
	SUSP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	SUSP_PART_ID  CHAR(2)  ,
	SUSP_ACTIVITY_DESC  VARCHAR(400)  
)
;


ALTER TABLE AMLCTR.LSTR_NARATIVE
	ADD CONSTRAINT  XPKLSTR_ACTION PRIMARY KEY (SUSP_PART_SEQ_NUM,SAR_ID)
;


CREATE TABLE AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	ALERT_ID  NUMERIC(15,0)  NOT NULL ,
	branch_key  NUMERIC(10)  NOT NULL ,
	date_key  NUMERIC(8,0)  NOT NULL ,
	time_key  NUMERIC(6)  NOT NULL ,
	account_key  NUMERIC(10)  NOT NULL ,
	transaction_key  NUMERIC(10)  NOT NULL ,
	transaction_currency_key  NUMERIC(5)  NOT NULL ,
	transaction_type_key  NUMERIC(10)  NOT NULL ,
	country_key  NUMERIC(5)  NOT NULL ,
	executing_party_key  NUMERIC(10)  NOT NULL ,
	associate_key  NUMERIC(10)  NOT NULL ,
	user_id  VARCHAR(35)  ,
	ext_party_account_key  NUMERIC(10)  NOT NULL ,
	currency_amount  NUMERIC(15,5)  NOT NULL ,
	currency_amount_in_txn_ccy  NUMERIC(15,5)  NOT NULL ,
	currency_amount_in_account_ccy  NUMERIC(15,5)  NOT NULL ,
	posted_date_key  NUMERIC(8)  ,
	debit_credit_indicator  CHAR(1)  ,
	update_date  DATE  
)
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.ALERT_ID IS 'System generated primary key for an alert.  Each SAR must have one to many alerts.
'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.branch_key IS 'Surrogate identifier..'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.date_key IS 'Note: this is normally a system-generated surrogate key, but for performance reasons we are using a numeric form of the date:

yyyymmdd'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.time_key IS 'System generated surrogate key.  Is NOT of form hhmmss in tables though it does come in that way in the stage files.'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.account_key IS 'System generated surrogate key.'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.transaction_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.transaction_currency_key IS 'Original transaction currency..'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.transaction_type_key IS 'Surrogate key'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.country_key IS 'Country where transaction occurred.  This is a short-cut primarily for wires to avoid having to query the wire dimensions..'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.executing_party_key IS 'Party that initiated the transaction.'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.associate_key IS 'System generated surrogate identifier'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.currency_amount IS 'Amount of the transaction expressed in the base/reporting currency..'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.currency_amount_in_txn_ccy IS 'Amount of the transaction expressed in the original currency of the transaction..'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.currency_amount_in_account_ccy IS 'The amount of the transaction in the denomination currency of the account.'
;


COMMENT ON COLUMN AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS.posted_date_key IS 'Date the transaction was posted to the source system.'
;


ALTER TABLE AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS
	ADD CONSTRAINT  XPKLSTR_SUSPICIOUS_TRANSACTION PRIMARY KEY (SAR_ID,ALERT_ID,branch_key,date_key,time_key,account_key,transaction_key,transaction_currency_key,transaction_type_key,country_key,executing_party_key,associate_key)
;




CREATE TABLE AMLCTR.SIC_LOOKUP
(
	CODE  CHAR(4)  ,
	SIC_DESCRIPTION  VARCHAR(50)  
)
;


CREATE TABLE AMLCTR.STR_ACCOUNT_HOLDER_CORP
(
	TRAN_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	DISP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	BUSS_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	BUSS_PART_ID  CHAR(2)  NOT NULL ,
	BUSS_FULL_NAME  VARCHAR(35)  ,
	BUSS_TYPE  VARCHAR(20)  ,
	BUSS_ST_ADDRESS  VARCHAR(30)  ,
	BUSS_CITY  VARCHAR(25)  ,
	BUSS_PROV  VARCHAR(20)  ,
	BUSS_COUNTRY  CHAR(2)  ,
	BUSS_POCODE  CHAR(9)  ,
	BUSS_PH  VARCHAR(20)  ,
	BUSS_PH_EXT  NUMERIC(10,0)  ,
	BUSS_INC  CHAR(14)  ,
	BUSS_INC_PROV  VARCHAR(20)  ,
	BUSS_INC_CNTRY  CHAR(2)  ,
	BUSS_SIGN_AUTH_1  VARCHAR(35)  ,
	BUSS_SIGN_AUTH_2  VARCHAR(35)  ,
	BUSS_SIGN_AUTH_3  VARCHAR(35)  
)
;


ALTER TABLE AMLCTR.STR_ACCOUNT_HOLDER_CORP
	ADD CONSTRAINT  XPKACCOUNT_HOLDER_CORP PRIMARY KEY (TRAN_SEQ_NUM,DISP_PART_SEQ_NUM,SAR_ID,BUSS_PART_SEQ_NUM)
;


CREATE TABLE AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL
(
	AH_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	TRAN_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	DISP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  ,
	AH_PART_ID  CHAR(2)  NOT NULL ,
	AH_SURNAME  VARCHAR(20)  ,
	AH_GIVEN_NAME  VARCHAR(15)  ,
	AH_INITIAL  CHAR(10)  ,
	AH_OTH_SURNAME  VARCHAR(20)  ,
	AH_OTH_GIVEN_NAME  VARCHAR(15)  ,
	AH_OTH_INITIAL  VARCHAR(10)  ,
	AH_ST_ADDRESS  VARCHAR(30)  ,
	AH_CITY  VARCHAR(20)  ,
	AH_PROV  VARCHAR(20)  ,
	AH_COUNTRY  CHAR(2)  ,
	AH_PCODE  CHAR(9)  ,
	AH_HOME_PH  VARCHAR(20)  ,
	AH_HOME_PH_EXT  NUMERIC(10,0)  ,
	AH_OFF_PH  VARCHAR(20)  ,
	AH_OFF_PH_EXT  NUMERIC(10,0)  ,
	AH_DOB  CHAR(8)  ,
	AH_IDENT  CHAR(1)  ,
	AH_OTH_IDENT  VARCHAR(20)  ,
	AH_ID_NUM  VARCHAR(20)  ,
	AH_RES_COUNTRY  CHAR(2)  ,
	AH_COUNTRY_CITIZEN  CHAR(2)  ,
	AH_ID_ISSUE_PROV  VARCHAR(20)  ,
	AH_ID_ISSUE_COUNTRY  CHAR(2)  ,
	AH_OCC  VARCHAR(20)  ,
	AH_EMPLYR  VARCHAR(35)  ,
	AH_EMPLYR_ST_ADDRESS  VARCHAR(30)  ,
	AH_EMPLYR_CITY  VARCHAR(20)  ,
	AH_EMPLYR_PROV  VARCHAR(20)  ,
	AH_EMPLYR_COUNTRY  CHAR(2)  ,
	AH_EMPLYR_POCODE  CHAR(9)  ,
	AH_EMPLYR_PH  CHAR(20)  ,
	AH_EMPLYR_PH_EXT  NUMERIC(10,0)  ,
	TP_REL_TO_AH  CHAR(1)  ,
	TP_REL_TO_AH_OTH  VARCHAR(20)  
)
;


ALTER TABLE AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL
	ADD CONSTRAINT  XPKACCOUNT_HOLDER_PERSONAL PRIMARY KEY (AH_PART_SEQ_NUM,TRAN_SEQ_NUM,DISP_PART_SEQ_NUM)
;


CREATE TABLE AMLCTR.STR_ACCOUNT_INFO
(
	ACCT_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	DISP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	TRAN_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	ACCT_PART_ID  CHAR(2)  NOT NULL ,
	ACCT_BRANCH_NUM  CHAR(12)  ,
	ACCT_NUMBER  CHAR(30)  ,
	ACCT_TYPE  CHAR(1)  ,
	ACCT_OTH_TYPE  VARCHAR(20)  ,
	ACCT_CURR  CHAR(3)  ,
	ACCT_FULL_NAME1  VARCHAR(45)  ,
	ACCT_FULL_NAME2  VARCHAR(45)  ,
	ACCT_FULL_NAME3  VARCHAR(45)  ,
	ACCT_OPEN_DATE  CHAR(8)  ,
	ACCT_CLOSE_DATE  CHAR(8)  ,
	ACCT_STATUS  CHAR(1)  
)
;


ALTER TABLE AMLCTR.STR_ACCOUNT_INFO
	ADD CONSTRAINT  XPKON_BEHALF PRIMARY KEY (ACCT_PART_SEQ_NUM,SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
;


CREATE TABLE AMLCTR.STR_ACTION
(
	PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	PART_ID  CHAR(2)  NOT NULL ,
	ACT_ACTION_DESC  VARCHAR(400)  
)
;


ALTER TABLE AMLCTR.STR_ACTION
	ADD CONSTRAINT  XPKSTR_ACTION PRIMARY KEY (PART_SEQ_NUM,SAR_ID)
;


CREATE TABLE AMLCTR.STR_BATCH_HEADER
(
	BATCH_SEQ_ID  NUMERIC(5,0)  NOT NULL ,
	BATCH_DATE  CHAR(8)  NOT NULL ,
	BATCH_TIME  NUMERIC(6,0)  NOT NULL ,
	RECORD_TYPE  CHAR(2)  ,
	CODE_FORMAT  CHAR(4)  ,
	REPORT_TYPE  CHAR(4)  ,
	REPORT_ENTITY_ID  CHAR(10)  ,
	CONTACT_SURNAME  VARCHAR(20)  ,
	CONTACT_GIVEN_NAME  VARCHAR(15)  ,
	CONTACT_PH_NUM  CHAR(20)  ,
	CONTACT_PH_NUM_EXT  NUMERIC(5,0)  ,
	BATCH_TYPE  CHAR(1)  ,
	REASON_CODE  NUMERIC(1,0)  ,
	SUB_HDR_COUNT  NUMERIC(5,0)  ,
	REPORT_COUNT  NUMERIC(5,0)  ,
	FORMAT_IND  NUMERIC(2,0)  ,
	OPER_MODE  CHAR(1)  ,
	UPDATE_DATE  CHAR(8)  ,
	UPDATE_ID  VARCHAR(35)  
)
;


ALTER TABLE AMLCTR.STR_BATCH_HEADER
	ADD CONSTRAINT  XPKSTR_BATCH PRIMARY KEY (BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME)
;


CREATE TABLE AMLCTR.STR_BATCH_RUN
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	BATCH_SEQ_NUM  NUMERIC(5,0)  NOT NULL ,
	RPT_SEQ_NUM  NUMERIC(5,0)  ,
	BATCH_DATE  CHAR(8)  ,
	BATCH_TIME  NUMERIC(8,0)  ,
	ACCT_NUMBER  CHAR(30)  
)
;


CREATE TABLE AMLCTR.STR_BATCH_SUB_HEADER
(
	SEQ_NUM  NUMERIC(5,0)  NOT NULL ,
	BATCH_SEQ_ID  NUMERIC(5,0)  NOT NULL ,
	BATCH_DATE  CHAR(8)  NOT NULL ,
	BATCH_TIME  NUMERIC(6,0)  NOT NULL ,
	REPORT_ENTITY_ID  CHAR(25)  ,
	REPORT_COUNT  NUMERIC(5,0)  ,
	RECORD_TYPE  CHAR(2)  
)
;


ALTER TABLE AMLCTR.STR_BATCH_SUB_HEADER
	ADD CONSTRAINT  XPKBATCH_SUB_HEADER PRIMARY KEY (SEQ_NUM,BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME)
;


CREATE TABLE AMLCTR.STR_DISPOSITION
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	DISP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	TRAN_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	DISP_PART_ID  CHAR(2)  NOT NULL ,
	DISP_TYPE  CHAR(1)  ,
	DISP_LIP_NUM  VARCHAR(20)  ,
	DISP_OTH_FUNDS  VARCHAR(20)  ,
	DISP_AMOUNT  NUMERIC(15,2)  ,
	DISP_CURRENCY  CHAR(3)  ,
	DISP_OTH_ENT_NAME  VARCHAR(35)  ,
	DISP_OTH_ACCT_NUM  CHAR(30)  ,
	DISP_ON_BEHALF_IND  CHAR(1)  
)
;


ALTER TABLE AMLCTR.STR_DISPOSITION
	ADD CONSTRAINT  XPKSTR_DISPOSITION PRIMARY KEY (SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
;


CREATE TABLE AMLCTR.STR_NARATIVE
(
	SUSP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	SUSP_PART_ID  CHAR(2)  NOT NULL ,
	SUSP_ACTIVITY_DESC  VARCHAR(400)  
)
;


ALTER TABLE AMLCTR.STR_NARATIVE
	ADD CONSTRAINT  XPKSTR_NARATIVE PRIMARY KEY (SUSP_PART_SEQ_NUM,SAR_ID)
;


CREATE TABLE AMLCTR.STR_REPORTING_ENTITY
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	PART_ID  CHAR(2)  NOT NULL ,
	RPT_ENT_ID  CHAR(12)  ,
	RPT_ENT_FULL_NAME  CHAR(35)  ,
	RPT_ENT_ST_ADDRESS  VARCHAR(30)  ,
	RPT_ENT_CITY  VARCHAR(25)  ,
	RPT_ENT_PROV  VARCHAR(2)  ,
	RPT_ENT_POCODE  VARCHAR(8)  ,
	RPT_ENT_TYPE  CHAR(1)  
)
;


ALTER TABLE AMLCTR.STR_REPORTING_ENTITY
	ADD CONSTRAINT  XPKREPORTING_ENTITY PRIMARY KEY (SAR_ID)
;


CREATE TABLE AMLCTR.STR_THIRD_PARTY
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	TP_PART_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	TRAN_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	TP_PART_ID  CHAR(2)  NOT NULL ,
	TP_SURNAME  VARCHAR(20)  ,
	TP_GIVEN_NAME  VARCHAR(15)  ,
	TP_INITIAL  CHAR(1)  ,
	TP_OTH_SURNAME  VARCHAR(20)  ,
	TP_OTH_GIVEN_NAME  VARCHAR(15)  ,
	TP_OTH_INITIAL  CHAR(1)  ,
	TP_CLIENT_NUM  VARCHAR(12)  ,
	TP_ST_ADDRESS  VARCHAR(30)  ,
	TP_CITY  VARCHAR(25)  ,
	TP_PROV  VARCHAR(20)  ,
	TP_COUNTRY  CHAR(2)  ,
	TP_POCODE  CHAR(9)  ,
	TP_COUNTRY_RES  CHAR(2)  ,
	TP_CITIZENSHIP  CHAR(2)  ,
	TP_HOME_PH  VARCHAR(20)  ,
	TP_HOME_PH_EXT  NUMERIC(10,0)  ,
	TP_IDENT  CHAR(1)  ,
	TP_IDENT_OTHER  VARCHAR(20)  ,
	TP_IDENT_NUM  VARCHAR(20)  ,
	TP_IDENT_ISSUE_PROV  VARCHAR(20)  ,
	TP_IDENT_ISSUE_COUNTRY  CHAR(2)  ,
	TP_DOB  CHAR(8)  ,
	TP_OCC  VARCHAR(20)  ,
	TP_BUSS_PH  CHAR(20)  ,
	TP_BUSS_PH_EXT  NUMERIC(10,0)  ,
	TP_EMPLYR  VARCHAR(35)  ,
	TP_EMPLYR_ADDRESS  VARCHAR(30)  ,
	TP_EMPLYR_CITY  VARCHAR(25)  ,
	TP_EMPLYR_PROV  VARCHAR(20)  ,
	TP_EMPLYR_COUNTRY  CHAR(2)  ,
	TP_EMPLYR_POCODE  CHAR(9)  ,
	TP_EMPLYR_BUSS_PH  VARCHAR(20)  ,
	TP_EMPLYR_BUSS_PH_EXT  NUMERIC(10,0)  
)
;


ALTER TABLE AMLCTR.STR_THIRD_PARTY
	ADD CONSTRAINT  XPKTHIRD_PARTY PRIMARY KEY (SAR_ID,TP_PART_SEQ_NUM,TRAN_SEQ_NUM)
;


CREATE TABLE AMLCTR.STR_TRANSACTIONS
(
	SAR_ID  NUMERIC(15,0)  NOT NULL ,
	TRAN_SEQ_NUM  NUMERIC(2,0)  NOT NULL ,
	TRAN_PART_ID  CHAR(2)  NOT NULL ,
	TRAN_DATE  CHAR(8)  ,
	TRAN_TIME  CHAR(4)  ,
	TRAN_BUS_HRS  CHAR(1)  ,
	TRAN_POST_DATE  CHAR(8)  ,
	TRAN_FUNDS_TYPE  CHAR(1)  ,
	TRAN_FUNDS_OTH  VARCHAR(20)  ,
	TRAN_AMOUNT  NUMERIC(13,2)  ,
	TRAN_CURRENCY  CHAR(3)  ,
	TRAN_OTH_PERSON_NAME  VARCHAR(35)  ,
	TRAN_OTH_ACCT_NUM  VARCHAR(50)  ,
	TRAN_METHOD  CHAR(1)  ,
	TRAN_OTH_METHOD  VARCHAR(20)  ,
	TELLER_ID  VARCHAR(15)  
)
;


ALTER TABLE AMLCTR.STR_TRANSACTIONS
	ADD CONSTRAINT  PK_STRTRANS PRIMARY KEY (SAR_ID,TRAN_SEQ_NUM)
;

ALTER TABLE AMLCTR.STR_ACCOUNT_HOLDER_CORP
	ADD CONSTRAINT  SARFK_28  FOREIGN KEY (SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_DISPOSITION(SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
;


ALTER TABLE AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL
	ADD CONSTRAINT  SARFK_27  FOREIGN KEY (SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_DISPOSITION(SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
;


ALTER TABLE AMLCTR.STR_ACCOUNT_INFO
	ADD CONSTRAINT  SARFK_30  FOREIGN KEY (SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_DISPOSITION(SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
;


ALTER TABLE AMLCTR.STR_ACTION
	ADD CONSTRAINT  SARFK_17  FOREIGN KEY (SAR_ID) REFERENCES AMLCTR.STR_REPORTING_ENTITY(SAR_ID)
;


ALTER TABLE AMLCTR.STR_BATCH_SUB_HEADER
	ADD CONSTRAINT  SARFK_11  FOREIGN KEY (BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME) REFERENCES AMLCTR.STR_BATCH_HEADER(BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME)
;


ALTER TABLE AMLCTR.STR_DISPOSITION
	ADD CONSTRAINT  SARFK_1  FOREIGN KEY (SAR_ID,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_TRANSACTIONS(SAR_ID,TRAN_SEQ_NUM)
;


ALTER TABLE AMLCTR.STR_NARATIVE
	ADD CONSTRAINT  SARFK_19  FOREIGN KEY (SAR_ID) REFERENCES AMLCTR.STR_REPORTING_ENTITY(SAR_ID)
;


ALTER TABLE AMLCTR.STR_THIRD_PARTY
	ADD CONSTRAINT  SARFK_36  FOREIGN KEY (SAR_ID,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_TRANSACTIONS(SAR_ID,TRAN_SEQ_NUM)
;


ALTER TABLE AMLCTR.STR_TRANSACTIONS
	ADD CONSTRAINT  SARFK_16  FOREIGN KEY (SAR_ID) REFERENCES AMLCTR.STR_REPORTING_ENTITY(SAR_ID)
;

create view BANK1KCTR.IDENTITY_DOCUMENT as locking row for access select * from AMLCTR.IDENTITY_DOCUMENT;
create view BANK1KCTR.FINTRAC_COUNTRY_LOOKUP as locking row for access select * from AMLCTR.FINTRAC_COUNTRY_LOOKUP;
create view BANK1KCTR.FINTRAC_TRANSACTION_TYPE_LOOKU as locking row for access select * from AMLCTR.FINTRAC_TRANSACTION_TYPE_LOOKU;
create view BANK1KCTR.FIN_CONTACT_CONTROL as locking row for access select * from AMLCTR.FIN_CONTACT_CONTROL;
create view BANK1KCTR.FIN_ENTITY_CONTROL as locking row for access select * from AMLCTR.FIN_ENTITY_CONTROL;
create view BANK1KCTR.LSTR_ACTION as locking row for access select * from AMLCTR.LSTR_ACTION;
create view BANK1KCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE as locking row for access select * from AMLCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE;
create view BANK1KCTR.LSTR_NARATIVE as locking row for access select * from AMLCTR.LSTR_NARATIVE;
create view BANK1KCTR.LSTR_SUSPICIOUS_TRANSACTIONS as locking row for access select * from AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS;
create view BANK1KCTR.STR_ACCOUNT_HOLDER_CORP as locking row for access select * from AMLCTR.STR_ACCOUNT_HOLDER_CORP;
create view BANK1KCTR.STR_ACCOUNT_HOLDER_PERSONAL as locking row for access select * from AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL;
create view BANK1KCTR.STR_ACCOUNT_INFO as locking row for access select * from AMLCTR.STR_ACCOUNT_INFO;
create view BANK1KCTR.STR_ACTION as locking row for access select * from AMLCTR.STR_ACTION;
create view BANK1KCTR.STR_BATCH_HEADER as locking row for access select * from AMLCTR.STR_BATCH_HEADER;
create view BANK1KCTR.STR_BATCH_RUN as locking row for access select * from AMLCTR.STR_BATCH_RUN;
create view BANK1KCTR.STR_BATCH_SUB_HEADER as locking row for access select * from AMLCTR.STR_BATCH_SUB_HEADER;
create view BANK1KCTR.STR_DISPOSITION as locking row for access select * from AMLCTR.STR_DISPOSITION;
create view BANK1KCTR.STR_NARATIVE as locking row for access select * from AMLCTR.STR_NARATIVE;
create view BANK1KCTR.STR_REPORTING_ENTITY as locking row for access select * from AMLCTR.STR_REPORTING_ENTITY;
create view BANK1KCTR.STR_THIRD_PARTY as locking row for access select * from AMLCTR.STR_THIRD_PARTY;
create view BANK1KCTR.STR_TRANSACTIONS as locking row for access select * from AMLCTR.STR_TRANSACTIONS;
create view BANK1KCTR.SIC_LOOKUP as locking row for access select * from AMLCTR.SIC_LOOKUP;

create view BANK2KCTR.IDENTITY_DOCUMENT as locking row for access select * from AMLCTR.IDENTITY_DOCUMENT;
create view BANK2KCTR.FINTRAC_COUNTRY_LOOKUP as locking row for access select * from AMLCTR.FINTRAC_COUNTRY_LOOKUP;
create view BANK2KCTR.FINTRAC_TRANSACTION_TYPE_LOOKU as locking row for access select * from AMLCTR.FINTRAC_TRANSACTION_TYPE_LOOKU;
create view BANK2KCTR.FIN_CONTACT_CONTROL as locking row for access select * from AMLCTR.FIN_CONTACT_CONTROL;
create view BANK2KCTR.FIN_ENTITY_CONTROL as locking row for access select * from AMLCTR.FIN_ENTITY_CONTROL;
create view BANK2KCTR.LSTR_ACTION as locking row for access select * from AMLCTR.LSTR_ACTION;
create view BANK2KCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE as locking row for access select * from AMLCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE;
create view BANK2KCTR.LSTR_NARATIVE as locking row for access select * from AMLCTR.LSTR_NARATIVE;
create view BANK2KCTR.LSTR_SUSPICIOUS_TRANSACTIONS as locking row for access select * from AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS;
create view BANK2KCTR.STR_ACCOUNT_HOLDER_CORP as locking row for access select * from AMLCTR.STR_ACCOUNT_HOLDER_CORP;
create view BANK2KCTR.STR_ACCOUNT_HOLDER_PERSONAL as locking row for access select * from AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL;
create view BANK2KCTR.STR_ACCOUNT_INFO as locking row for access select * from AMLCTR.STR_ACCOUNT_INFO;
create view BANK2KCTR.STR_ACTION as locking row for access select * from AMLCTR.STR_ACTION;
create view BANK2KCTR.STR_BATCH_HEADER as locking row for access select * from AMLCTR.STR_BATCH_HEADER;
create view BANK2KCTR.STR_BATCH_RUN as locking row for access select * from AMLCTR.STR_BATCH_RUN;
create view BANK2KCTR.STR_BATCH_SUB_HEADER as locking row for access select * from AMLCTR.STR_BATCH_SUB_HEADER;
create view BANK2KCTR.STR_DISPOSITION as locking row for access select * from AMLCTR.STR_DISPOSITION;
create view BANK2KCTR.STR_NARATIVE as locking row for access select * from AMLCTR.STR_NARATIVE;
create view BANK2KCTR.STR_REPORTING_ENTITY as locking row for access select * from AMLCTR.STR_REPORTING_ENTITY;
create view BANK2KCTR.STR_THIRD_PARTY as locking row for access select * from AMLCTR.STR_THIRD_PARTY;
create view BANK2KCTR.STR_TRANSACTIONS as locking row for access select * from AMLCTR.STR_TRANSACTIONS;
create view BANK2KCTR.SIC_LOOKUP as locking row for access select * from AMLCTR.SIC_LOOKUP;

